package de.uni_passau.fim.PADAS.group3.DataDash.model;

import java.util.List;
import java.util.Optional;
import java.util.UUID;

import org.springframework.stereotype.Service;

@Service
public class DatasetService {
    private dataRepository datasetRepository;

    public DatasetService(dataRepository datasetRepository) {
        this.datasetRepository = datasetRepository;
    }

    public List<Dataset> getAllDatasets() {
        return datasetRepository.findAll();
    }

    public Dataset getDatasetById(UUID id) {
        return datasetRepository.getDatasetById(id);
    }

    public void addDataset(Dataset dataset) {
        datasetRepository.save(dataset);
    }

    public void updateDatasetTitle(UUID id, String title) {
        datasetRepository.getDatasetById(id).setTitle(title);
    }

    public void deleteDataset(UUID id) {
        Dataset dataset = datasetRepository.getDatasetById(id);
        datasetRepository.delete(dataset);
    }

    public List<Dataset> getDatasetsByTitle(String title) {
        return datasetRepository.findByTitle(title);
    }

    public List<Dataset> getDatasetsByTitleLike(String title) {
        return datasetRepository.findByTitleLike(title);
    }

    public List<Dataset> findByDescriptionLike(String description) {
        return datasetRepository.findByDescriptionLike(description);
    }

    public List<Dataset> getDatasetsByAuthorLike(String author) {
        return datasetRepository.findByAuthorLike(author);
    }

    public List<Dataset> getDatasetsByType(Type type) {
        return datasetRepository.findByType(type);
    }

    public List<Dataset> getDatasetsByAbstLike(String abst) {
        return datasetRepository.findByAbstLike(abst);
    }

    public List<Dataset> getDatasetsByRaitingGreaterThan(float raiting) {
        return datasetRepository.findByRaitingGreaterThan(raiting);
    }

    public void upvoteDataset(UUID id) {
        Dataset dataset = datasetRepository.getDatasetById(id);
        dataset.upvote();
        datasetRepository.save(dataset);
    }

    public void downvoteDataset(UUID id) {
        Dataset dataset = datasetRepository.getDatasetById(id);
        dataset.downvote();
        datasetRepository.save(dataset);
    }

    //public List<Dataset> getDatasetsBy(String title, String author, String abst, String description) {
    //    return datasetRepository.findBy(title, author, abst, description);
    //}

    public List<Dataset> getDatasetsByOptionalCriteria(String title, String description, String author, String abst,
            Type type, Float raiting) {
        String[] categories = null;
        return datasetRepository.findByOptionalCriteria(Optional.ofNullable(title), Optional.ofNullable(description),
                Optional.ofNullable(author), Optional.ofNullable(abst), Optional.ofNullable(type),
                Optional.ofNullable(categories), Optional.ofNullable(raiting));
    }
}